# tellweather

A Python package to get weather reports for any location.

## Usage

Following query on terminal will provide you the weather details of "mumbai" for next 3 days.

```
tellweather -q mumbai -d 3
```